==> zjkj-wzxt-impl-3.0.0-20240806.101840-30-sources.jar: com/ejianc/wzxt/check/bean/CheckDetailEntity.java <==
package com.ejianc.wzxt.check.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 消耗材-验收明细子表
 *
 * @author generator
 *
 */
 @TableName("ejc_wzxt_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit")
    private String unit; // 单位名称
    @TableField(value="unit_id")
    private Long unitId; // 单位主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="deliver_num")
    private BigDecimal deliverNum; // 发货数量
    @TableField(value="check_num")
    private BigDecimal checkNum; // 验收数量
    @TableField(value="order_num")
    private BigDecimal orderNum; // 订单量
    @TableField(value="plan_num")
    private BigDecimal planNum; // 计划量
    @TableField(value="plan_surplus_num")
    private BigDecimal planSurplusNum; // 计划剩余量
    @TableField(value="check_sum_num")
    private BigDecimal checkSumNum; // 已验收数量
    @TableField(value="quality_code")
    private String qualityCode; // 质保资料及编号
    @TableField(value="check_result")
    private Integer checkResult; // 验收结论：1合格、2不合格、3待检
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="check_type")
    private Integer checkType; // 验收来源，1-自制验收,2-零星材料验收，3-发货验收
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细id
    @TableField(value="detail_coefficient")
    private BigDecimal detailCoefficient; // 换算系数
    @TableField(value="detail_net_weight")
    private BigDecimal detailNetWeight; // 净重
    @TableField(value="detail_net_weight_coefficient")
    private BigDecimal detailNetWeightCoefficient; // 单位换算后净重（千克）
    @TableField(value="detail_automatic_weigh")
    private Integer detailAutomaticWeigh; // 自动称重设置（0：自动称重，1非自动称重）
    @TableField(value="check_id")
    private Long checkId; // 主表Id


    public Integer getDetailAutomaticWeigh() {
        return detailAutomaticWeigh;
    }

    public void setDetailAutomaticWeigh(Integer detailAutomaticWeigh) {
        this.detailAutomaticWeigh = detailAutomaticWeigh;
    }

    public BigDecimal getDetailNetWeightCoefficient() {
        return detailNetWeightCoefficient;
    }

    public void setDetailNetWeightCoefficient(BigDecimal detailNetWeightCoefficient) {
        this.detailNetWeightCoefficient = detailNetWeightCoefficient;
    }

    public BigDecimal getDetailCoefficient() {
        return detailCoefficient;
    }

    public void setDetailCoefficient(BigDecimal detailCoefficient) {
        this.detailCoefficient = detailCoefficient;
    }

    public BigDecimal getDetailNetWeight() {
        return detailNetWeight;
    }

    public void setDetailNetWeight(BigDecimal detailNetWeight) {
        this.detailNetWeight = detailNetWeight;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }


    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDeliverNum() {
        return deliverNum;
    }

    public void setDeliverNum(BigDecimal deliverNum) {
        this.deliverNum = deliverNum;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public BigDecimal getPlanSurplusNum() {
        return planSurplusNum;
    }

    public void setPlanSurplusNum(BigDecimal planSurplusNum) {
        this.planSurplusNum = planSurplusNum;
    }

    public BigDecimal getCheckSumNum() {
        return checkSumNum;
    }

    public void setCheckSumNum(BigDecimal checkSumNum) {
        this.checkSumNum = checkSumNum;
    }

    public String getQualityCode() {
        return qualityCode;
    }

    public void setQualityCode(String qualityCode) {
        this.qualityCode = qualityCode;
    }

    public Integer getCheckResult() {
        return checkResult;
    }

    public void setCheckResult(Integer checkResult) {
        this.checkResult = checkResult;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
}

==> zjkj-wzxt-impl-3.0.0-20240814.071805-76-sources.jar: com/ejianc/wzxt/check/bean/CheckDetailEntity.java <==
package com.ejianc.wzxt.check.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 消耗材-验收明细子表
 *
 * @author generator
 *
 */
 @TableName("ejc_wzxt_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit")
    private String unit; // 单位名称
    @TableField(value="unit_id")
    private Long unitId; // 单位主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="deliver_num")
    private BigDecimal deliverNum; // 发货数量
    @TableField(value="check_num")
    private BigDecimal checkNum; // 验收数量
    @TableField(value="order_num")
    private BigDecimal orderNum; // 订单量
    @TableField(value="plan_num")
    private BigDecimal planNum; // 计划量
    @TableField(value="plan_surplus_num")
    private BigDecimal planSurplusNum; // 计划剩余量
    @TableField(value="check_sum_num")
    private BigDecimal checkSumNum; // 已验收数量
    @TableField(value="quality_code")
    private String qualityCode; // 质保资料及编号
    @TableField(value="check_result")
    private Integer checkResult; // 验收结论：1合格、2不合格、3待检
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="check_type")
    private Integer checkType; // 验收来源，1-自制验收,2-零星材料验收，3-发货验收
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细id
    @TableField(value="detail_coefficient")
    private BigDecimal detailCoefficient; // 换算系数
    @TableField(value="detail_net_weight")
    private BigDecimal detailNetWeight; // 净重
    @TableField(value="detail_net_weight_coefficient")
    private BigDecimal detailNetWeightCoefficient; // 单位换算后净重（千克）
    @TableField(value="detail_automatic_weigh")
    private Integer detailAutomaticWeigh; // 自动称重设置（0：自动称重，1非自动称重）
    @TableField(value="check_id")
    private Long checkId; // 主表Id
    @TableField(value="month_plan_id")
    private Long monthPlanId; // 来源id
    @TableField(value="month_plan_detail_id")
    private Long monthPlanDetailId; // 来源明细id

    public Integer getDetailAutomaticWeigh() {
        return detailAutomaticWeigh;
    }

    public void setDetailAutomaticWeigh(Integer detailAutomaticWeigh) {
        this.detailAutomaticWeigh = detailAutomaticWeigh;
    }

    public BigDecimal getDetailNetWeightCoefficient() {
        return detailNetWeightCoefficient;
    }

    public void setDetailNetWeightCoefficient(BigDecimal detailNetWeightCoefficient) {
        this.detailNetWeightCoefficient = detailNetWeightCoefficient;
    }

    public BigDecimal getDetailCoefficient() {
        return detailCoefficient;
    }

    public void setDetailCoefficient(BigDecimal detailCoefficient) {
        this.detailCoefficient = detailCoefficient;
    }

    public BigDecimal getDetailNetWeight() {
        return detailNetWeight;
    }

    public void setDetailNetWeight(BigDecimal detailNetWeight) {
        this.detailNetWeight = detailNetWeight;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }


    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDeliverNum() {
        return deliverNum;
    }

    public void setDeliverNum(BigDecimal deliverNum) {
        this.deliverNum = deliverNum;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public BigDecimal getPlanSurplusNum() {
        return planSurplusNum;
    }

    public void setPlanSurplusNum(BigDecimal planSurplusNum) {
        this.planSurplusNum = planSurplusNum;
    }

    public BigDecimal getCheckSumNum() {
        return checkSumNum;
    }

    public void setCheckSumNum(BigDecimal checkSumNum) {
        this.checkSumNum = checkSumNum;
    }

    public String getQualityCode() {
        return qualityCode;
    }

    public void setQualityCode(String qualityCode) {
        this.qualityCode = qualityCode;
    }

    public Integer getCheckResult() {
        return checkResult;
    }

    public void setCheckResult(Integer checkResult) {
        this.checkResult = checkResult;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }

    public Long getMonthPlanId() {
        return monthPlanId;
    }

    public void setMonthPlanId(Long monthPlanId) {
        this.monthPlanId = monthPlanId;
    }

    public Long getMonthPlanDetailId() {
        return monthPlanDetailId;
    }

    public void setMonthPlanDetailId(Long monthPlanDetailId) {
        this.monthPlanDetailId = monthPlanDetailId;
    }
}
